# Change Log

## [v1.4](https://github.com/thewizardplusplus/hh-stats/tree/v1.4) (2017-06-28)

**Closed issues:**

- Convert an analysis time to a local time zone [\#23](https://github.com/thewizardplusplus/hh-stats/issues/23)
- Simplify a processing of the KeyboardInterrupt exception [\#25](https://github.com/thewizardplusplus/hh-stats/issues/25)
- Use an uppercase in names of services files [\#27](https://github.com/thewizardplusplus/hh-stats/issues/27)
- Add an example of a file with skills aliases [\#28](https://github.com/thewizardplusplus/hh-stats/issues/28)
- Prepare the package for a publication [\#30](https://github.com/thewizardplusplus/hh-stats/issues/30)
- Log:
    - Make a log colorful [\#24](https://github.com/thewizardplusplus/hh-stats/issues/24)
    - Simplify log messages [\#26](https://github.com/thewizardplusplus/hh-stats/issues/26)
- Versions:
    - Specify a package version in the \_\_init\_\_.py file [\#19](https://github.com/thewizardplusplus/hh-stats/issues/19)
    - Specify a minimal Python version in the setup.py file [\#20](https://github.com/thewizardplusplus/hh-stats/issues/20)
    - Specify dependencies versions in the setup.py file [\#21](https://github.com/thewizardplusplus/hh-stats/issues/21)
    - Refactor the version message [\#22](https://github.com/thewizardplusplus/hh-stats/issues/22)

**Fixed bugs:**

- Use absolute paths in the setup.py file [\#29](https://github.com/thewizardplusplus/hh-stats/issues/29)

## [v1.3](https://github.com/thewizardplusplus/hh-stats/tree/v1.3) (2017-04-03)

**Closed issues:**

- Support a vacancies loading from some JSON files simultaneously [\#18](https://github.com/thewizardplusplus/hh-stats/issues/18)
- Specify an analysis period as a range with a start and an end [\#13](https://github.com/thewizardplusplus/hh-stats/issues/13)
- Support a fractional request frequency [\#12](https://github.com/thewizardplusplus/hh-stats/issues/12)

**Fixed bugs:**

- Filter duplicated skills in an every vacancy [\#17](https://github.com/thewizardplusplus/hh-stats/issues/17)
- Automatically set a version number in setup.py [\#15](https://github.com/thewizardplusplus/hh-stats/issues/15)
- Filter duplicated vacancies before a stats collection [\#14](https://github.com/thewizardplusplus/hh-stats/issues/14)

## [v1.2](https://github.com/thewizardplusplus/hh-stats/tree/v1.2) (2017-03-15)

**Closed issues:**

- Separate unseparated skills [\#11](https://github.com/thewizardplusplus/hh-stats/issues/11)
- Support a raw output format \(a vacancy list in a JSON format\) [\#10](https://github.com/thewizardplusplus/hh-stats/issues/10)
- Support a vacancies loading from a JSON file instead hh.ru service API [\#9](https://github.com/thewizardplusplus/hh-stats/issues/9)
- Filter vacancies without skills [\#8](https://github.com/thewizardplusplus/hh-stats/issues/8)

## [v1.1](https://github.com/thewizardplusplus/hh-stats/tree/v1.1) (2017-03-14)

**Closed issues:**

- Throw an error on an exceeding of the search limit [\#7](https://github.com/thewizardplusplus/hh-stats/issues/7)
- Support skills aliases [\#4](https://github.com/thewizardplusplus/hh-stats/issues/4)
- Work around search restrictions via date\_from&date\_to parameters [\#3](https://github.com/thewizardplusplus/hh-stats/issues/3)
- Use the currency key from the /dictionaries HH API endpoint for a currencies conversion [\#2](https://github.com/thewizardplusplus/hh-stats/issues/2)
- Support a specifying of search fields for a search query [\#1](https://github.com/thewizardplusplus/hh-stats/issues/1)

**Fixed bugs:**

- Filter archived vacancies [\#6](https://github.com/thewizardplusplus/hh-stats/issues/6)
- Filter closed vacancies [\#5](https://github.com/thewizardplusplus/hh-stats/issues/5)

## [v1.0](https://github.com/thewizardplusplus/hh-stats/tree/v1.0) (2017-03-08)

*This change log was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator).*
